==> cga-py-0.0.3.dev0.tar.gz: cga-py-0.0.3.dev0/cga_py/__init__.py <==
from .base_objects import (
    e_1,
    e_2,
    e_3,
    e_i,
    e_o,
    eps_1,
    eps_2,
    eps_3,
    q_i,
    q_j,
    q_k,
)
from .conditions import study_cond, study_var, null_quadric
from .four_quaternions import (
    arr_to_quat,
    quat_to_arr,
    rotor_to_quat,
    quat_to_rotor,
    vectorial,
    scalar,
)
from .geom_generators import (
    point,
    normalize_point,
    point_to_cartesian,
    sphere,
    normalize_sphere,
    sphere_to_cartesian,
    plane,
    normalize_plane,
    plane_to_cartesian,
)
from .multivector import cga_object
from .operators import act, com, anti_com, n_grade, r_norm, l_norm
from .random import (
    rand_rational,
    rand_point,
    rand_sphere,
    rand_plane,
    rand_rotor,
    rand_rot_poly,
    rand_zero,
)
from .kinematic_polynomials import poly_act
from .dorst_motions import iso_scale, transv
from .visualization import point_p_act


from .permutations import (
    e_12,
    e_13,
    e_1i,
    e_1o,
    e_23,
    e_2i,
    e_2o,
    e_3i,
    e_3o,
    e_io,
    e_21,
    e_31,
    e_i1,
    e_o1,
    e_32,
    e_i2,
    e_o2,
    e_i3,
    e_o3,
    e_oi,
    e_123,
    e_12i,
    e_12o,
    e_13i,
    e_13o,
    e_1io,
    e_23i,
    e_23o,
    e_2io,
    e_3io,
    e_132,
    e_1i2,
    e_1o2,
    e_1i3,
    e_1o3,
    e_1oi,
    e_2i3,
    e_2o3,
    e_2oi,
    e_3oi,
    e_213,
    e_21i,
    e_21o,
    e_31i,
    e_31o,
    e_i1o,
    e_32i,
    e_32o,
    e_i2o,
    e_i3o,
    e_231,
    e_2i1,
    e_2o1,
    e_3i1,
    e_3o1,
    e_io1,
    e_3i2,
    e_3o2,
    e_io2,
    e_io3,
    e_312,
    e_i12,
    e_o12,
    e_i13,
    e_o13,
    e_o1i,
    e_i23,
    e_o23,
    e_o2i,
    e_o3i,
    e_321,
    e_i21,
    e_o21,
    e_i31,
    e_o31,
    e_oi1,
    e_i32,
    e_o32,
    e_oi2,
    e_oi3,
    e_123i,
    e_123o,
    e_12io,
    e_13io,
    e_23io,
    e_12i3,
    e_12o3,
    e_12oi,
    e_13oi,
    e_23oi,
    e_132i,
    e_132o,
    e_1i2o,
    e_1i3o,
    e_2i3o,
    e_13i2,
    e_13o2,
    e_1io2,
    e_1io3,
    e_2io3,
    e_1i23,
    e_1o23,
    e_1o2i,
    e_1o3i,
    e_2o3i,
    e_1i32,
    e_1o32,
    e_1oi2,
    e_1oi3,
    e_2oi3,
    e_213i,
    e_213o,
    e_21io,
    e_31io,
    e_32io,
    e_21i3,
    e_21o3,
    e_21oi,
    e_31oi,
    e_32oi,
    e_231i,
    e_231o,
    e_2i1o,
    e_3i1o,
    e_3i2o,
    e_23i1,
    e_23o1,
    e_2io1,
    e_3io1,
    e_3io2,
    e_2i13,
    e_2o13,
    e_2o1i,
    e_3o1i,
    e_3o2i,
    e_2i31,
    e_2o31,
    e_2oi1,
    e_3oi1,
    e_3oi2,
    e_312i,
    e_312o,
    e_i12o,
    e_i13o,
    e_i23o,
    e_31i2,
    e_31o2,
    e_i1o2,
    e_i1o3,
    e_i2o3,
    e_321i,
    e_321o,
    e_i21o,
    e_i31o,
    e_i32o,
    e_32i1,
    e_32o1,
    e_i2o1,
    e_i3o1,
    e_i3o2,
    e_3i12,
    e_3o12,
    e_io12,
    e_io13,
    e_io23,
    e_3i21,
    e_3o21,
    e_io21,
    e_io31,
    e_io32,
    e_i123,
    e_o123,
    e_o12i,
    e_o13i,
    e_o23i,
    e_i132,
    e_o132,
    e_o1i2,
    e_o1i3,
    e_o2i3,
    e_i213,
    e_o213,
    e_o21i,
    e_o31i,
    e_o32i,
    e_i231,
    e_o231,
    e_o2i1,
    e_o3i1,
    e_o3i2,
    e_i312,
    e_o312,
    e_oi12,
    e_oi13,
    e_oi23,
    e_i321,
    e_o321,
    e_oi21,
    e_oi31,
    e_oi32,
    e_123io,
    e_123oi,
    e_12i3o,
    e_12io3,
    e_12o3i,
    e_12oi3,
    e_132io,
    e_132oi,
    e_13i2o,
    e_13io2,
    e_13o2i,
    e_13oi2,
    e_1i23o,
    e_1i2o3,
    e_1i32o,
    e_1i3o2,
    e_1io23,
    e_1io32,
    e_1o23i,
    e_1o2i3,
    e_1o32i,
    e_1o3i2,
    e_1oi23,
    e_1oi32,
    e_213io,
    e_213oi,
    e_21i3o,
    e_21io3,
    e_21o3i,
    e_21oi3,
    e_231io,
    e_231oi,
    e_23i1o,
    e_23io1,
    e_23o1i,
    e_23oi1,
    e_2i13o,
    e_2i1o3,
    e_2i31o,
    e_2i3o1,
    e_2io13,
    e_2io31,
    e_2o13i,
    e_2o1i3,
    e_2o31i,
    e_2o3i1,
    e_2oi13,
    e_2oi31,
    e_312io,
    e_312oi,
    e_31i2o,
    e_31io2,
    e_31o2i,
    e_31oi2,
    e_321io,
    e_321oi,
    e_32i1o,
    e_32io1,
    e_32o1i,
    e_32oi1,
    e_3i12o,
    e_3i1o2,
    e_3i21o,
    e_3i2o1,
    e_3io12,
    e_3io21,
    e_3o12i,
    e_3o1i2,
    e_3o21i,
    e_3o2i1,
    e_3oi12,
    e_3oi21,
    e_i123o,
    e_i12o3,
    e_i132o,
    e_i13o2,
    e_i1o23,
    e_i1o32,
    e_i213o,
    e_i21o3,
    e_i231o,
    e_i23o1,
    e_i2o13,
    e_i2o31,
    e_i312o,
    e_i31o2,
    e_i321o,
    e_i32o1,
    e_i3o12,
    e_i3o21,
    e_io123,
    e_io132,
    e_io213,
    e_io231,
    e_io312,
    e_io321,
    e_o123i,
    e_o12i3,
    e_o132i,
    e_o13i2,
    e_o1i23,
    e_o1i32,
    e_o213i,
    e_o21i3,
    e_o231i,
    e_o23i1,
    e_o2i13,
    e_o2i31,
    e_o312i,
    e_o31i2,
    e_o321i,
    e_o32i1,
    e_o3i12,
    e_o3i21,
    e_oi123,
    e_oi132,
    e_oi213,
    e_oi231,
    e_oi312,
    e_oi321,
)

==> cga-py-1.3.0.tar.gz: cga-py-1.3.0/cga_py/__init__.py <==
from .base_objects import (
    e_1,
    e_2,
    e_3,
    e_i,
    e_o,
    eps_1,
    eps_2,
    eps_3,
    q_i,
    q_j,
    q_k,
)
from .conditions import study_cond, study_var, null_quadric
from .four_quaternions import (
    arr_to_quat,
    quat_to_arr,
    rotor_to_quat,
    quat_to_rotor,
    vectorial,
    scalar,
)
from .geom_generators import (
    point,
    normalize_point,
    point_to_cartesian,
    sphere,
    normalize_sphere,
    sphere_to_cartesian,
    plane,
    normalize_plane,
    plane_to_cartesian,
)
from .multivector import cga_object
from .operators import act, com, anti_com, n_grade, r_norm, l_norm
from .random_gen import (
    rand_rational,
    rand_point,
    rand_sphere,
    rand_plane,
    rand_rotor,
    rand_rot_poly,
    rand_zero,
)
from .kinematic_polynomials import poly_act
from .dorst_motions import iso_scale, transv
from .visualization import point_p_act, point_cube_gen, sphere_gen
from .errors import GeometryError
from .permutations import (
    e_12,
    e_13,
    e_1i,
    e_1o,
    e_23,
    e_2i,
    e_2o,
    e_3i,
    e_3o,
    e_io,
    e_21,
    e_31,
    e_i1,
    e_o1,
    e_32,
    e_i2,
    e_o2,
    e_i3,
    e_o3,
    e_oi,
    e_123,
    e_12i,
    e_12o,
    e_13i,
    e_13o,
    e_1io,
    e_23i,
    e_23o,
    e_2io,
    e_3io,
    e_132,
    e_1i2,
    e_1o2,
    e_1i3,
    e_1o3,
    e_1oi,
    e_2i3,
    e_2o3,
    e_2oi,
    e_3oi,
    e_213,
    e_21i,
    e_21o,
    e_31i,
    e_31o,
    e_i1o,
    e_32i,
    e_32o,
    e_i2o,
    e_i3o,
    e_231,
    e_2i1,
    e_2o1,
    e_3i1,
    e_3o1,
    e_io1,
    e_3i2,
    e_3o2,
    e_io2,
    e_io3,
    e_312,
    e_i12,
    e_o12,
    e_i13,
    e_o13,
    e_o1i,
    e_i23,
    e_o23,
    e_o2i,
    e_o3i,
    e_321,
    e_i21,
    e_o21,
    e_i31,
    e_o31,
    e_oi1,
    e_i32,
    e_o32,
    e_oi2,
    e_oi3,
    e_123i,
    e_123o,
    e_12io,
    e_13io,
    e_23io,
    e_12i3,
    e_12o3,
    e_12oi,
    e_13oi,
    e_23oi,
    e_132i,
    e_132o,
    e_1i2o,
    e_1i3o,
    e_2i3o,
    e_13i2,
    e_13o2,
    e_1io2,
    e_1io3,
    e_2io3,
    e_1i23,
    e_1o23,
    e_1o2i,
    e_1o3i,
    e_2o3i,
    e_1i32,
    e_1o32,
    e_1oi2,
    e_1oi3,
    e_2oi3,
    e_213i,
    e_213o,
    e_21io,
    e_31io,
    e_32io,
    e_21i3,
    e_21o3,
    e_21oi,
    e_31oi,
    e_32oi,
    e_231i,
    e_231o,
    e_2i1o,
    e_3i1o,
    e_3i2o,
    e_23i1,
    e_23o1,
    e_2io1,
    e_3io1,
    e_3io2,
    e_2i13,
    e_2o13,
    e_2o1i,
    e_3o1i,
    e_3o2i,
    e_2i31,
    e_2o31,
    e_2oi1,
    e_3oi1,
    e_3oi2,
    e_312i,
    e_312o,
    e_i12o,
    e_i13o,
    e_i23o,
    e_31i2,
    e_31o2,
    e_i1o2,
    e_i1o3,
    e_i2o3,
    e_321i,
    e_321o,
    e_i21o,
    e_i31o,
    e_i32o,
    e_32i1,
    e_32o1,
    e_i2o1,
    e_i3o1,
    e_i3o2,
    e_3i12,
    e_3o12,
    e_io12,
    e_io13,
    e_io23,
    e_3i21,
    e_3o21,
    e_io21,
    e_io31,
    e_io32,
    e_i123,
    e_o123,
    e_o12i,
    e_o13i,
    e_o23i,
    e_i132,
    e_o132,
    e_o1i2,
    e_o1i3,
    e_o2i3,
    e_i213,
    e_o213,
    e_o21i,
    e_o31i,
    e_o32i,
    e_i231,
    e_o231,
    e_o2i1,
    e_o3i1,
    e_o3i2,
    e_i312,
    e_o312,
    e_oi12,
    e_oi13,
    e_oi23,
    e_i321,
    e_o321,
    e_oi21,
    e_oi31,
    e_oi32,
    e_123io,
    e_123oi,
    e_12i3o,
    e_12io3,
    e_12o3i,
    e_12oi3,
    e_132io,
    e_132oi,
    e_13i2o,
    e_13io2,
    e_13o2i,
    e_13oi2,
    e_1i23o,
    e_1i2o3,
    e_1i32o,
    e_1i3o2,
    e_1io23,
    e_1io32,
    e_1o23i,
    e_1o2i3,
    e_1o32i,
    e_1o3i2,
    e_1oi23,
    e_1oi32,
    e_213io,
    e_213oi,
    e_21i3o,
    e_21io3,
    e_21o3i,
    e_21oi3,
    e_231io,
    e_231oi,
    e_23i1o,
    e_23io1,
    e_23o1i,
    e_23oi1,
    e_2i13o,
    e_2i1o3,
    e_2i31o,
    e_2i3o1,
    e_2io13,
    e_2io31,
    e_2o13i,
    e_2o1i3,
    e_2o31i,
    e_2o3i1,
    e_2oi13,
    e_2oi31,
    e_312io,
    e_312oi,
    e_31i2o,
    e_31io2,
    e_31o2i,
    e_31oi2,
    e_321io,
    e_321oi,
    e_32i1o,
    e_32io1,
    e_32o1i,
    e_32oi1,
    e_3i12o,
    e_3i1o2,
    e_3i21o,
    e_3i2o1,
    e_3io12,
    e_3io21,
    e_3o12i,
    e_3o1i2,
    e_3o21i,
    e_3o2i1,
    e_3oi12,
    e_3oi21,
    e_i123o,
    e_i12o3,
    e_i132o,
    e_i13o2,
    e_i1o23,
    e_i1o32,
    e_i213o,
    e_i21o3,
    e_i231o,
    e_i23o1,
    e_i2o13,
    e_i2o31,
    e_i312o,
    e_i31o2,
    e_i321o,
    e_i32o1,
    e_i3o12,
    e_i3o21,
    e_io123,
    e_io132,
    e_io213,
    e_io231,
    e_io312,
    e_io321,
    e_o123i,
    e_o12i3,
    e_o132i,
    e_o13i2,
    e_o1i23,
    e_o1i32,
    e_o213i,
    e_o21i3,
    e_o231i,
    e_o23i1,
    e_o2i13,
    e_o2i31,
    e_o312i,
    e_o31i2,
    e_o321i,
    e_o32i1,
    e_o3i12,
    e_o3i21,
    e_oi123,
    e_oi132,
    e_oi213,
    e_oi231,
    e_oi312,
    e_oi321,
)
